@@ -40,7 +40,6 @@ class Experiment(object):
         self, config: dict = None, config_string=None, basepath=None, custom_layout=None,
     ):
 
-
         self._alfred_version = __version__
         self._session_status = None
 
@@ -427,3 +426,7 @@ class Experiment(object):
 
     def add_session(self, s):
         self._session = self._session + "." + s if self._session else s
+
+    def __iadd__(self, other):
+        self.append(other)
+        return self
